@@ -139,9 +139,7 @@ main(int argc, char *argv[])
       }
       break;
     case 'i':
-      if (!strcmp(optarg, "3"))
-        io_version = 3;
-      else if (!strcmp(optarg, "4"))
+      if (!strcmp(optarg, "4"))
         io_version = 4;
       else
         io_version = -1;
@@ -261,8 +259,9 @@ main(int argc, char *argv[])
 		 global_pa, sarg, &fatal_parse_err,
 		 &nonfatal_parse_err, &warnings, &read_boulder_record_res);
     destroy_pr_append_str_data(&p3_settings_path);
-    /* Check if the thermodynamical alignment flag was given */
-    if (global_pa->thermodynamic_alignment == 1)
+    /* Check if any thermodynamical alignment flag was given */
+    if ((global_pa->thermodynamic_oligo_alignment == 1) || 
+	(global_pa->thermodynamic_template_alignment == 1))
       read_thermodynamic_parameters();
   }
 
@@ -327,14 +326,17 @@ main(int argc, char *argv[])
       break; /* There were no more boulder records */
     }
 
-    /* Check if the thermodynamical alignment flag was given and the
+    /* Check if any thermodynamical alignment flag was given and the
        path to the parameter files changed - we need to reread them */
-    if ((global_pa->thermodynamic_alignment == 1)
+    if (((global_pa->thermodynamic_oligo_alignment == 1) ||
+	 (global_pa->thermodynamic_template_alignment == 1))
 	&& (thermodynamic_path_changed == 1))
       read_thermodynamic_parameters();
 
-    /* Check that we found the thermodynamic parameters in case the flag was set to 1. */
-    if ((global_pa->thermodynamic_alignment == 1) && (thermodynamic_params_path == NULL)) {
+    /* Check that we found the thermodynamic parameters in case any thermodynamic flag was set to 1. */
+    if (((global_pa->thermodynamic_oligo_alignment == 1) ||
+	 (global_pa->thermodynamic_template_alignment == 1))
+	&& (thermodynamic_params_path == NULL)) {
       /* no parameter directory found, error */
       printf("PRIMER_ERROR=thermodynamic approach chosen, but path to thermodynamic parameters not specified\n=\n");
       exit(-1);
@@ -342,7 +344,7 @@ main(int argc, char *argv[])
 
     input_found = 1;
     if ((global_pa->primer_task == generic)
-                && (global_pa->pick_internal_oligo == 1)){
+	&& (global_pa->pick_internal_oligo == 1)){
       PR_ASSERT(global_pa->pick_internal_oligo);
     }
 
@@ -399,14 +401,10 @@ main(int argc, char *argv[])
     retval = choose_primers(global_pa, sarg);
     if (NULL == retval) exit(-2); /* Out of memory. */
 
-    /* This is old code to make it compatible with version 3 input.
-       In future versions it can be deleted!
-       If it was necessary to use a left_input, right_input,
+    /* If it was necessary to use a left_input, right_input,
        or internal_oligo_input primer that was
        unacceptable, then add warnings. */
-
-    if (global_pa->pick_anyway && (io_version == 3
-                || format_output)) {
+    if (global_pa->pick_anyway && format_output) {
       if (sarg->left_input) {
         add_must_use_warnings(&retval->warnings,
                               "Left primer", &retval->fwd.expl);
@@ -420,7 +418,6 @@ main(int argc, char *argv[])
                               "Hybridization probe", &retval->intl.expl);
       }
     }
-    /* End of the old code for compatibility. */
 
     if (pr_is_empty(&retval->glob_err)
         && pr_is_empty(&retval->per_sequence_err)) {
@@ -464,7 +461,8 @@ main(int argc, char *argv[])
          End of the primary working loop */
 
   /* To avoid being distracted when looking for leaks: */
-  if (global_pa->thermodynamic_alignment == 1)
+  if ((global_pa->thermodynamic_oligo_alignment == 1) ||
+      (global_pa->thermodynamic_template_alignment == 1))
     destroy_thal_structures();
   p3_destroy_global_settings(global_pa);
   global_pa = NULL;
@@ -543,8 +541,8 @@ print_usage()
 
   fprintf(stderr, "\n\nUSAGE: %s %s %s %s %s %s %s %s %s %s\n", pr_program_name,
           "[-format_output]", 
-	  "[-default_version=1|-default_version=2",
-	  "[-io_version=3|-io_version=4]", 
+	  "[-default_version=1|-default_version=2]",
+	  "[-io_version=4]", 
 	  "[-p3_settings_file=<file_path>]",
 	  "[-echo_settings_file]",
 	  "[-strict_tags]", 
